@@ -1,7 +1,7 @@
 #!/bin/bash
 
 cd `dirname $0`
-PYTHONPATH=".." python -m coverage run --source greenado -m pytest $@
+PYTHONPATH=".." python -m coverage run --branch --source greenado -m pytest $@
 if [ "$?" != "0" ]; then
 	exit 1
 fi
